@@ -400,6 +400,40 @@ runtime_evaluate_helper <- function(class_name=NULL, id=NULL, list_num=NULL, dis
     if(isTRUE(dispatch_event))".dispatchEvent(new CustomEvent('click'))"))
 }
 
+# get the bounding box (position and size) of an element relative to the viewport.
+get_element_bbox <- function(selector) {
+  script <- sprintf("(() => {
+    const el = document.querySelector('%s');
+    const box = el.getBoundingClientRect();
+    return {
+      left: box.left,
+      top: box.top,
+      width: box.width,
+      height: box.height,
+      center_x: box.left + box.width / 2,
+      center_y: box.top + box.height / 2
+    };
+  })()", selector)
+  runtime_evaluate(script)
+}
+
+mouseMoved <- function(selector=NULL){
+  position <- if(is.null(selector)){
+    list(center_x=0, center_y=0)
+  }else if(is.list(selector)){
+    selector
+  }else if(is.character(selector)){
+    get_element_bbox(selector)
+  }else stop("unrecognized selector")
+  remDr$Input$dispatchMouseEvent(
+    type = "mouseMoved",
+    x = position$center_x,
+    y = position$center_y
+  )
+  Sys.sleep(0.3)
+  position
+}
+
 driverjs_click_class <- function(class_name,list_num=0){
   runtime_evaluate_helper(
     class_name = class_name,
@@ -426,3 +460,34 @@ driverjs_get <- function(html=getHTML()){
   }
   out.list
 }
+
+check_aligned_box_collisions <- function(html_doc, xpath) {
+  box_groups <- getNodeSet(html_doc, xpath)
+  box_info <- lapply(box_groups, function(group) {
+    rect <- getNodeSet(group, './/rect')[[1]]
+    attrs <- xmlAttrs(rect)
+    list(
+      x = as.numeric(attrs["x"]),
+      y = as.numeric(attrs["y"]),
+      width = as.numeric(attrs["width"]),
+      height = as.numeric(attrs["height"])
+    )
+  })
+  has_overlap <- FALSE
+  first_overlap_msg <- NULL
+  for (i in 1:(length(box_info) - 1)) {
+    for (j in (i + 1):length(box_info)) {
+      box1 <- box_info[[i]]
+      box2 <- box_info[[j]]
+      x_overlap <- box1$x < (box2$x + box2$width) && (box1$x + box1$width) > box2$x
+      y_overlap <- box1$y < (box2$y + box2$height) && (box1$y + box1$height) > box2$y
+      if (x_overlap && y_overlap) {
+        has_overlap <- TRUE
+        first_overlap_msg <- paste("Overlap detected between boxes", i, "and", j)
+        break
+      }
+    }
+    if (has_overlap) break
+  }
+  expect_false(has_overlap, info = first_overlap_msg)
+}
